@@ -13,14 +13,20 @@ import markdown
 from bs4 import BeautifulSoup
 from typer import Argument, Exit, Option, colors, run, secho
 
-from . import templates
-from .models import Contacts, Convos
+from sigexport import templates
+from sigexport.models import Contacts, Convos
+from sigexport import __version__
 
 log = False
 
 DATA_DELIM = "-----DATA-----"
 
 
+def version_callback(value: bool) -> None:
+    if value:
+        print(f"v{__version__}")
+        raise Exit()
+
 def source_location() -> Path:
     """Get OS-dependent source location."""
 
@@ -470,10 +476,13 @@ def main(
     use_docker: bool = Option(
         False, help="Use Docker container for SQLCipher extraction"
     ),
-    docker_image: str = Option("carderne/sigexport:latest", help="Docker image to use"),
+    docker_image: str = Option(None, help="Docker image to use"),
     print_data: bool = Option(
         False, help="Print extracted DB data and exit (for use by Docker container)"
     ),
+    version: Optional[bool] = Option(
+        None, "--version", callback=version_callback
+    ),
 ):
     """
     Read the Signal directory and output attachments and chat files to DEST directory.
@@ -511,6 +520,8 @@ def main(
             use_docker = True
 
     if use_docker:
+        if not docker_image:
+            docker_image = f"carderne/sigexport:v{__version__}"
         secho(
             "Using Docker to extract data, this may take a while the first time!",
             fg=colors.BLUE,
@@ -555,7 +566,7 @@ def main(
             secho(data)
             raise Exit(1)
     else:
-        from .data import fetch_data
+        from sigexport.data import fetch_data
 
         convos, contacts = fetch_data(
             db_file,
